@@ -1,20 +1,24 @@
 """Base finder for finding Room/Message"""
 from re import Pattern
 from typing import (
+    Any,
     Callable,
-    Optional,
     Union,
-    List,
+    List, Coroutine,
 )
-
 from wechaty_plugin_contrib.config import (
     Room,
     Contact,
     Message
 )
 
+from wechaty import Wechaty
 
-FinderOption = Union[str, Pattern, bool, Callable[[Union[Contact, Room, Message]], List[Union[Room, Contact]]]]
+FinderOption = Union[
+    str, Pattern, bool,
+    Callable[[Union[Contact, Room, Message]], List[Union[Room, Contact]]],
+    Callable[[Any], Coroutine[Any, Any, List[Any]]]
+]
 FinderOptions = Union[FinderOption, List[FinderOption]]
 
 
@@ -25,5 +29,5 @@ class Finder:
         else:
             self.options = [option]
 
-    def match(self, target) -> bool:
+    async def match(self, bot: Wechaty) -> List[Any]:
         raise NotImplementedError
